<?xml version="1.0" encoding="UTF-8" ?>
<!-- showme.xsl
 | DITA showme javascript support - this is the shell XSL for integrating the code modules
 | DITA tutorial and sample gallery launching support - adds javascript to support links to galleries
-->

<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:saxon="http://icl.com/saxon"
                xmlns:xt="http://www.jclark.com/xt"
                extension-element-prefixes="saxon xt">

<!-- stylesheet imports -->
<!-- the main dita to xhtml converter -->
<xsl:import href="idit2htm.xsl"/>

<!--expected format for showme links:
href: viewlet-name
navtitle/linktext: show me
format: viewlet
type: showme
-->


<!-- Output XHTML with XML syntax, use UFT-8 encoding="UTF-8", transitional XHTML.
     Prevent indenting to conserve space on output. -->
<!-- <xsl:output method="xml" -->
<xsl:output method="saxon:xhtml"
            encoding="UTF-8"
            indent="no"
            doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
            doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"
/>

<!--overriding relinfo-links to ignore showme links-->
<xsl:template name="relinfo-links">
     <!--other info- - not currently sorting by role, since already mixing any number of types in here-->
     <!--if there are links not covered by any of the other routines - ie, not in a linklist, not a child or descendant, not a concept/task/reference, not ancestor/next/previous, not prerequisite - create a section for them and create the links-->
     <xsl:if test="descendant::*
[contains(@class, ' topic/link ')]
[not(ancestor::*[contains(@class,' topic/linklist ')])]
          [not(@role='child' or @role='descendant' or @role='ancestor' or @role='parent' or @role='next' or @role='previous' or @type='concept' or @type='task' or @type='reference' or @type='showme')]
          [not(@importance='required' and (not(@role) or @role='sibling' or @role='friend' or @role='cousin'))]">
          <div>
          <strong>
             <xsl:call-template name="getString">
                  <xsl:with-param name="stringName" select="'Related information'"/>
               </xsl:call-template>
          </strong>
       <!--once section is created, create the links, using the same rules as bove plus a uniqueness check-->
       <xsl:for-each select="descendant::*
          [not(ancestor::*[contains(@class,' topic/linklist ')])]
          [generate-id(.)=generate-id(key('link',concat(ancestor::*[contains(@class, ' topic/related-links ')]/parent::*[contains(@class, ' topic/topic ')]/@id, ' ', @href,@type,@role,@platform,@audience,@importance,@outputclass,@keyref,@scope,@format,@otherrole,@product,@otherprops,@rev,@class,child::*))[1])]
[contains(@class, ' topic/link ')]
          [not(@role='child' or @role='descendant' or @role='ancestor' or @role='parent' or @role='next' or @role='previous' or @type='concept' or @type='task' or @type='reference' or @type='showme')]
          [not(@importance='required' and (not(@role) or @role='sibling' or @role='friend' or @role='cousin'))]">
          <xsl:apply-templates select="."/>
       </xsl:for-each>

          </div>
     </xsl:if>
</xsl:template>


<!--overriding shortdesc template to introduce showme link before shortdesc-->
<xsl:template match="*[contains(@class,' topic/shortdesc ')]" mode="outofline">
<div>
  <xsl:for-each select="following-sibling::*[contains(@class,' topic/related-links ')]/descendant::*[contains(@class,' topic/link ')][@format='viewlet'][@type='showme']">
	<h5><a>
		<xsl:attribute name="href">javascript:popup_window( '../../../../com.ibm.etools.viewlet.doc/swf/<xsl:value-of select="@href"/>_viewlet_swf.html?noframes=true', '<xsl:value-of select="@href"/>', 950, 750 );</xsl:attribute>
		<xsl:attribute name="decor">none</xsl:attribute>
		<img src="../../../../com.ibm.etools.viewlet.doc/images/camera2.gif" border="none" align="middle" alt=""></img><font color="blue"><xsl:apply-templates/></font></a></h5>
   </xsl:for-each>
  <xsl:call-template name="commonattributes"/>
  <xsl:apply-templates/>
</div>
</xsl:template>


<!--overriding gen-user-scripts stub to call showme javascript-->
<xsl:template name="gen-user-scripts">
	<xsl:call-template name="showme-script"/>
	<xsl:call-template name="gallery-script"/>
</xsl:template>


<xsl:template name="showme-script">
<script language="JavaScript">
    function popup_window( url, id, width, height )
    {
      popup = window.open( url, id, 'toolbar=no,scrollbars=no,location=no,statusbar=no,menubar=no,resizable=no,width=' + width + ',height=' + height + ',left=,top=' );
      popup.focus();
    }
</script>
</xsl:template>

<xsl:template name="gallery-script">
<script language="JavaScript" src="help/liveHelp.js"></script>

</xsl:template>

</xsl:stylesheet>
